euroMix-package:
Forensic calculations including mixtures with pedigrees
Description
Mixtures are simulated and LR (likelihood ratio) calculations are performed. Complex pedigrees, possibly with inbreeding,
theta correction, mutation and silent alleles, are allowed.
General conditioning is also accounted in the simulation. There is also a function
pvalue.machine that calculates tail probabilities for LR-s.
Details
|
Package: |
| euroMix |
|
Type: |
| Package |
|
Version: |
| 1.1 |
|
Date: |
| 2015-12-07 |
The linkdat is created using the R-package
paramlink. This could be done within R or by reading files on Merlin format using
the linkdat function. Some of the functions require Merlin to be installed.
References
See Egeland et al. (2013)